.. commit signature, "date_str author_str sha_str"
   Maintain spacing of "History" and "GitHub Log" titles

History
=======

GitHub Log
----------


Mercurial Log
-------------

* 2017-07-03 13:53 -0700 Charlie Taylor
    - First draft of docs

* 2017-07-02 16:22 -0700 Charlie Taylor
    - Changed to run on Ubuntu

* 2017-07-02 14:06 -0700 Charlie Taylor
    - Added Pillow to requirements

* 2017-07-02 13:42 -0700 Charlie Taylor
    - got python 3 working

* 2017-07-02 12:04 -0700 Charlie Taylor
    - started docs and some image display limits

* 2017-07-01 22:34 -0700 Charlie Taylor
    - Added Distortion Error estimates

* 2017-07-01 19:38 -0700 Charlie Taylor
    - Added cross-hairs

* 2017-07-01 19:36 -0700 Charlie Taylor
    - Added cross-hairs

* 2017-07-01 14:23 -0700 Charlie Taylor
    - Added Clipboard Logic

* 2017-07-01 14:18 -0700 Charlie Taylor
    - Added sort by x

* 2017-07-01 14:04 -0700 Charlie Taylor
    - Added sort by x

* 2017-07-01 11:20 -0700 Charlie Taylor
    - added Exit/Quit logic

* 2017-06-30 23:48 -0700 Charlie Taylor
    - Basic working digitizer

* 2017-06-30 21:31 -0700 Charlie Taylor
    - all pack, but working zoom/pan

* 2017-06-30 13:19 -0700 Charlie Taylor
    - First commit



* Jun 29, 2017
    - (by: sonofeft)
        - First Created DigiPlot with PyHatch

